function make_pp(Cw,makeplot)

% Creates a piecewise polynomial (pp) form of the forcing function in Cw.
% When makeplot=1, a plot is made to view the splines.

% Author : Tjalling Jager 
% Date:   Jan 2014
% Web support: http://www.debtox.info/byom.html

global pp_coll pp_scen

scen = Cw(1,2:end); % scenarios in this call

if ~isempty(pp_coll) % it might have been already defined
    if sum(ismember(pp_scen,scen))>0
        error('Some scenarios already have a splined set. Check your script.')
    end
    l_old = length(pp_scen); % length of old vector
    pp_scen = [pp_scen scen]; % add to the existing range
else
    l_old = 0;
    pp_scen = scen; % remember scenarios in first entry of cell array
end

if exist('griddedInterpolant') == 2 
    % newer versions of Matlab have different way of making interpolation then pp
    for i = l_old+1:l_old+length(scen) % run through scenarios
        pp_coll{i} = griddedInterpolant(Cw(2:end,1),Cw(2:end,i+1-l_old),'pchip'); % cubic hermite
        %     pp_coll{i} = griddedInterpolant(Cw(2:end,1),Cw(2:end,i+1-l_old),'linear'); % linear
    end
else % use the old version ...
    for i = l_old+1:l_old+length(scen) % run through scenarios
        pp_coll{i} = interp1(Cw(2:end,1),Cw(2:end,i+1-l_old),'pchip','pp'); % cubic hermite
        %     pp_coll{i} = interp1(Cw(2:end,1),Cw(2:end,i+1-l_old),'linear','pp'); % linear
    end
end

if makeplot == 1 % only make a plot if asked to
    figure
    hold on
    
    T = Cw(2:end,1); % time vector in data set
    t = linspace(min(T),max(T),200); % model vector
    
    % make one plot with subplots for each state variable
    n = ceil(sqrt(length(scen)));
    m = ceil(length(scen)/n);
    
    for i = l_old+1:l_old+length(scen) % run through scenarios
        subplot(m,n,i-l_old)
        hold on
        
        if exist('griddedInterpolant') == 2
            c = pp_coll{i}(t);
        else
            c = ppval(pp_coll{i},t); % use the pp form already provided
        end
        
        plot(t,c,'k-','LineWidth',2)
        plot(T,Cw(2:end,1+i-l_old),'ko','MarkerFaceColor','w','LineWidth',2)
        xlabel('time','FontSize',12)
        ylabel(['forcing, scenario ',num2str(pp_scen(i))],'FontSize',12)
        set(gca,'LineWidth',1,'FontSize',12) % adapt axis formatting
    end
end

drawnow